@@ -18,40 +18,43 @@
  */
 
 #include "dynamicprofilepanel.h"
-#include "multilangmgr.h"
+#include "../rtengine/dynamicprofile.h"
 #include "../rtengine/profilestore.h"
 #include "../rtengine/rtengine.h"
-#include "../rtengine/dynamicprofile.h"
+#include "multilangmgr.h"
+#include <iomanip>
 #include <sstream>
 #include <string>
-#include <iomanip>
-
 
 //-----------------------------------------------------------------------------
 // DynamicProfilePanel::EditDialog
 //-----------------------------------------------------------------------------
 
-DynamicProfilePanel::EditDialog::EditDialog(const Glib::ustring &title, Gtk::Window &parent):
-    Gtk::Dialog(title, parent)
+DynamicProfilePanel::EditDialog::EditDialog(const Glib::ustring &title,
+                                            Gtk::Window &parent)
+    : Gtk::Dialog(title, parent)
 {
     profilepath_ = Gtk::manage(new ProfileStoreComboBox());
     Gtk::HBox *hb = Gtk::manage(new Gtk::HBox());
-    hb->pack_start(*Gtk::manage(new Gtk::Label(M("DYNPROFILEEDITOR_PROFILE"))), false, false, 4);
+    hb->pack_start(*Gtk::manage(new Gtk::Label(M("DYNPROFILEEDITOR_PROFILE"))),
+                   false, false, 4);
     hb->pack_start(*profilepath_, true, true, 2);
     get_content_area()->pack_start(*hb, Gtk::PACK_SHRINK, 4);
 
     add_optional(M("EXIFFILTER_CAMERA"), has_camera_, camera_);
     add_optional(M("EXIFFILTER_LENS"), has_lens_, lens_);
     add_optional(M("EXIFFILTER_FILETYPE"), has_filetype_, filetype_);
-    add_optional(M("EXIFFILTER_SOFTWARE"), has_software_, software_);    
-    
+    add_optional(M("EXIFFILTER_SOFTWARE"), has_software_, software_);
+
     imagetype_ = Gtk::manage(new MyComboBoxText());
-    imagetype_->append(Glib::ustring("(") + M("DYNPROFILEEDITOR_IMGTYPE_ANY") + ")");
+    imagetype_->append(Glib::ustring("(") + M("DYNPROFILEEDITOR_IMGTYPE_ANY") +
+                       ")");
     imagetype_->append(M("DYNPROFILEEDITOR_IMGTYPE_RAW"));
     imagetype_->append(M("DYNPROFILEEDITOR_IMGTYPE_NONRAW"));
     imagetype_->set_active(0);
     hb = Gtk::manage(new Gtk::HBox());
-    hb->pack_start(*Gtk::manage(new Gtk::Label(M("EXIFFILTER_IMAGETYPE"))), false, false, 4);
+    hb->pack_start(*Gtk::manage(new Gtk::Label(M("EXIFFILTER_IMAGETYPE"))),
+                   false, false, 4);
     hb->pack_start(*imagetype_, true, true, 2);
     get_content_area()->pack_start(*hb, Gtk::PACK_SHRINK, 4);
 
@@ -61,23 +64,28 @@ DynamicProfilePanel::EditDialog::EditDialog(const Glib::ustring &title, Gtk::Win
     add_range(M("EXIFFILTER_SHUTTER"), shutterspeed_min_, shutterspeed_max_);
     add_range(M("EXIFFILTER_EXPOSURECOMPENSATION"), expcomp_min_, expcomp_max_);
 
-    has_customdata_ = Gtk::manage(new Gtk::CheckButton(M("DYNPROFILEEDITOR_CUSTOMDATA")));
+    has_customdata_ =
+        Gtk::manage(new Gtk::CheckButton(M("DYNPROFILEEDITOR_CUSTOMDATA")));
     hb = Gtk::manage(new Gtk::HBox());
     hb->pack_start(*has_customdata_, Gtk::PACK_SHRINK, 4);
 
     customdata_ = Gtk::TextBuffer::create();
     customdata_view_ = Gtk::manage(new Gtk::TextView(customdata_));
-    setExpandAlignProperties(has_customdata_, false, false, Gtk::ALIGN_FILL, Gtk::ALIGN_START);
-    setExpandAlignProperties(customdata_view_, true, true, Gtk::ALIGN_FILL, Gtk::ALIGN_FILL);
+    setExpandAlignProperties(has_customdata_, false, false, Gtk::ALIGN_FILL,
+                             Gtk::ALIGN_START);
+    setExpandAlignProperties(customdata_view_, true, true, Gtk::ALIGN_FILL,
+                             Gtk::ALIGN_FILL);
     customdata_view_->set_border_width(1);
     Gtk::ScrolledWindow *sw = Gtk::manage(new Gtk::ScrolledWindow());
-    setExpandAlignProperties(sw, true, false, Gtk::ALIGN_FILL, Gtk::ALIGN_START);
+    setExpandAlignProperties(sw, true, false, Gtk::ALIGN_FILL,
+                             Gtk::ALIGN_START);
     sw->set_min_content_height(100);
     sw->set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_ALWAYS);
     sw->add(*customdata_view_);
     hb->pack_start(*sw, true, true, 2);
     get_content_area()->pack_start(*hb, Gtk::PACK_SHRINK, 4);
-    customdata_view_->set_tooltip_markup(M("DYNPROFILEEDITOR_CUSTOMDATA_TOOLTIP"));
+    customdata_view_->set_tooltip_markup(
+        M("DYNPROFILEEDITOR_CUSTOMDATA_TOOLTIP"));
 
     add_button(M("GENERAL_OK"), 1);
     add_button(M("GENERAL_CANCEL"), 2);
@@ -87,9 +95,7 @@ DynamicProfilePanel::EditDialog::EditDialog(const Glib::ustring &title, Gtk::Win
     show_all_children();
 }
 
-
-void DynamicProfilePanel::EditDialog::set_rule(
-    const DynamicProfileRule &rule)
+void DynamicProfilePanel::EditDialog::set_rule(const DynamicProfileRule &rule)
 {
     iso_min_->set_value(rule.iso.min);
     iso_max_->set_value(rule.iso.max);
@@ -117,7 +123,7 @@ void DynamicProfilePanel::EditDialog::set_rule(
 
     has_filetype_->set_active(rule.filetype.enabled);
     filetype_->set_text(rule.filetype.value);
-    
+
     if (!rule.imagetype.enabled) {
         imagetype_->set_active(0);
     } else if (rule.imagetype.value == "raw") {
@@ -171,7 +177,7 @@ DynamicProfileRule DynamicProfilePanel::EditDialog::get_rule()
 
     ret.filetype.enabled = has_filetype_->get_active();
     ret.filetype.value = filetype_->get_text();
-    
+
     ret.imagetype.enabled = imagetype_->get_active_row_number() > 0;
     switch (imagetype_->get_active_row_number()) {
     case 1:
@@ -197,7 +203,8 @@ DynamicProfileRule DynamicProfilePanel::EditDialog::get_rule()
             line = line.substr(i);
             auto pos = line.find("=");
             if (pos != std::string::npos) {
-                ret.customdata.value.emplace_back(line.substr(0, pos), line.substr(pos+1));
+                ret.customdata.value.emplace_back(line.substr(0, pos),
+                                                  line.substr(pos + 1));
             } else {
                 ret.customdata.value.emplace_back(line, "");
             }
@@ -221,17 +228,15 @@ void DynamicProfilePanel::EditDialog::set_ranges()
     iso_min_->set_value(default_rule.iso.min);
     iso_max_->set_value(default_rule.iso.max);
 
-#define DOIT_(name)                                    \
-    name ## _min_->set_digits(1);                      \
-    name ## _max_->set_digits(1);                      \
-    name ## _min_->set_increments(0.1, 1);             \
-    name ## _max_->set_increments(0.1, 1);             \
-    name ## _min_->set_range(default_rule. name .min,  \
-                             default_rule. name .max); \
-    name ## _max_->set_range(default_rule. name .min,  \
-                             default_rule. name .max); \
-    name ## _min_->set_value(default_rule. name .min); \
-    name ## _max_->set_value(default_rule. name .max)
+#define DOIT_(name)                                                            \
+    name##_min_->set_digits(1);                                                \
+    name##_max_->set_digits(1);                                                \
+    name##_min_->set_increments(0.1, 1);                                       \
+    name##_max_->set_increments(0.1, 1);                                       \
+    name##_min_->set_range(default_rule.name.min, default_rule.name.max);      \
+    name##_max_->set_range(default_rule.name.min, default_rule.name.max);      \
+    name##_min_->set_value(default_rule.name.min);                             \
+    name##_max_->set_value(default_rule.name.max)
 
     DOIT_(fnumber);
     DOIT_(focallen);
@@ -244,9 +249,9 @@ void DynamicProfilePanel::EditDialog::set_ranges()
     profilepath_->setInternalEntry();
 }
 
-
 void DynamicProfilePanel::EditDialog::add_range(const Glib::ustring &name,
-        Gtk::SpinButton *&from, Gtk::SpinButton *&to)
+                                                Gtk::SpinButton *&from,
+                                                Gtk::SpinButton *&to)
 {
     Gtk::HBox *hb = Gtk::manage(new Gtk::HBox());
     hb->pack_start(*Gtk::manage(new Gtk::Label(name)), false, false, 4);
@@ -260,7 +265,9 @@ void DynamicProfilePanel::EditDialog::add_range(const Glib::ustring &name,
     get_content_area()->pack_start(*hb, Gtk::PACK_SHRINK, 4);
 }
 
-void DynamicProfilePanel::EditDialog::add_optional(const Glib::ustring &name, Gtk::CheckButton *&check, Gtk::Entry *&field)
+void DynamicProfilePanel::EditDialog::add_optional(const Glib::ustring &name,
+                                                   Gtk::CheckButton *&check,
+                                                   Gtk::Entry *&field)
 {
     check = Gtk::manage(new Gtk::CheckButton(name));
     Gtk::HBox *hb = Gtk::manage(new Gtk::HBox());
@@ -271,19 +278,18 @@ void DynamicProfilePanel::EditDialog::add_optional(const Glib::ustring &name, Gt
     field->set_tooltip_text(M("DYNPROFILEEDITOR_ENTRY_TOOLTIP"));
 }
 
-
 //-----------------------------------------------------------------------------
 // DynamicProfilePanel
 //-----------------------------------------------------------------------------
 
-DynamicProfilePanel::DynamicProfilePanel():
-    vbox_(Gtk::ORIENTATION_VERTICAL),
-    button_up_(M("DYNPROFILEEDITOR_MOVE_UP")),
-    button_down_(M("DYNPROFILEEDITOR_MOVE_DOWN")),
-    button_new_(M("DYNPROFILEEDITOR_NEW")),
-    button_edit_(M("DYNPROFILEEDITOR_EDIT")),
-    button_delete_(M("DYNPROFILEEDITOR_DELETE")),
-    button_reset_(M("FILEBROWSER_RESETDEFAULTPROFILE"))
+DynamicProfilePanel::DynamicProfilePanel()
+    : vbox_(Gtk::ORIENTATION_VERTICAL),
+      button_up_(M("DYNPROFILEEDITOR_MOVE_UP")),
+      button_down_(M("DYNPROFILEEDITOR_MOVE_DOWN")),
+      button_new_(M("DYNPROFILEEDITOR_NEW")),
+      button_edit_(M("DYNPROFILEEDITOR_EDIT")),
+      button_delete_(M("DYNPROFILEEDITOR_DELETE")),
+      button_reset_(M("FILEBROWSER_RESETDEFAULTPROFILE"))
 {
     add(vbox_);
 
@@ -319,17 +325,17 @@ DynamicProfilePanel::DynamicProfilePanel():
     treemodel_ = Gtk::ListStore::create(columns_);
     treeview_.set_model(treemodel_);
 
-#define ADD_COL(which, lbl) \
-    do {                       \
-        auto cell = Gtk::manage(new Gtk::CellRendererText());           \
-        int cols_count = treeview_.append_column( M(lbl), *cell); \
-        auto col = treeview_.get_column(cols_count - 1);                \
-                                                                        \
-        if (col) {                                                      \
-            col->set_cell_data_func(                                   \
-                *cell, sigc::mem_fun(                                  \
-                    *this, &DynamicProfilePanel::render_ ## which));  \
-        } \
+#define ADD_COL(which, lbl)                                                    \
+    do {                                                                       \
+        auto cell = Gtk::manage(new Gtk::CellRendererText());                  \
+        int cols_count = treeview_.append_column(M(lbl), *cell);               \
+        auto col = treeview_.get_column(cols_count - 1);                       \
+                                                                               \
+        if (col) {                                                             \
+            col->set_cell_data_func(                                           \
+                *cell,                                                         \
+                sigc::mem_fun(*this, &DynamicProfilePanel::render_##which));   \
+        }                                                                      \
     } while (false)
 
     ADD_COL(profilepath, "DYNPROFILEEDITOR_PROFILE");
@@ -344,12 +350,11 @@ DynamicProfilePanel::DynamicProfilePanel():
     ADD_COL(software, "EXIFFILTER_SOFTWARE");
     ADD_COL(imagetype, "EXIFFILTER_IMAGETYPE");
     ADD_COL(customdata, "DYNPROFILEEDITOR_CUSTOMDATA");
-    
+
     show_all_children();
     reset();
 }
 
-
 void DynamicProfilePanel::reset()
 {
     treemodel_->clear();
@@ -358,7 +363,6 @@ void DynamicProfilePanel::reset()
     }
 }
 
-
 void DynamicProfilePanel::update_rule(Gtk::TreeModel::Row row,
                                       const DynamicProfileRule &rule)
 {
@@ -382,8 +386,8 @@ void DynamicProfilePanel::add_rule(const DynamicProfileRule &rule)
     update_rule(row, rule);
 }
 
-
-DynamicProfileRule DynamicProfilePanel::to_rule(Gtk::TreeModel::Row row, int serial)
+DynamicProfileRule DynamicProfilePanel::to_rule(Gtk::TreeModel::Row row,
+                                                int serial)
 {
     DynamicProfileRule ret;
     ret.serial_number = serial;
@@ -402,7 +406,6 @@ DynamicProfileRule DynamicProfilePanel::to_rule(Gtk::TreeModel::Row row, int ser
     return ret;
 }
 
-
 void DynamicProfilePanel::render_profilepath(
     Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter)
 {
@@ -418,25 +421,21 @@ void DynamicProfilePanel::render_profilepath(
     }
 }
 
-
-#define RENDER_RANGE_(tp, name, tostr)                              \
-    auto row = *iter;                                                   \
-    Gtk::CellRendererText *ct = static_cast<Gtk::CellRendererText *>(cell); \
-    DynamicProfileRule::Range<tp> r = row[columns_. name];         \
-    DynamicProfileRule dflt;                                       \
-    if (r.min > dflt.name.min || r.max < dflt.name.max) {               \
-        auto value = tostr(r.min) + " - " + tostr(r.max);               \
-        ct->property_text() = value;                                    \
-    } else {                                                            \
-        ct->property_text() = "";                                       \
+#define RENDER_RANGE_(tp, name, tostr)                                         \
+    auto row = *iter;                                                          \
+    Gtk::CellRendererText *ct = static_cast<Gtk::CellRendererText *>(cell);    \
+    DynamicProfileRule::Range<tp> r = row[columns_.name];                      \
+    DynamicProfileRule dflt;                                                   \
+    if (r.min > dflt.name.min || r.max < dflt.name.max) {                      \
+        auto value = tostr(r.min) + " - " + tostr(r.max);                      \
+        ct->property_text() = value;                                           \
+    } else {                                                                   \
+        ct->property_text() = "";                                              \
     }
 
+namespace {
 
-namespace
-{
-
-template <class V>
-Glib::ustring to_str(V n, int precision = 1)
+template <class V> Glib::ustring to_str(V n, int precision = 1)
 {
     std::ostringstream buf;
     buf << std::setprecision(precision) << std::fixed << n;
@@ -445,112 +444,104 @@ Glib::ustring to_str(V n, int precision = 1)
 
 } // namespace
 
-void DynamicProfilePanel::render_iso(
-    Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter)
+void DynamicProfilePanel::render_iso(Gtk::CellRenderer *cell,
+                                     const Gtk::TreeModel::iterator &iter)
 {
     RENDER_RANGE_(int, iso, to_str);
 }
 
-
-void DynamicProfilePanel::render_fnumber(
-    Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter)
+void DynamicProfilePanel::render_fnumber(Gtk::CellRenderer *cell,
+                                         const Gtk::TreeModel::iterator &iter)
 {
-    RENDER_RANGE_(double, fnumber,
-    [](double f) {
+    RENDER_RANGE_(double, fnumber, [](double f) {
         return std::string("f/") +
                rtengine::FramesMetaData::apertureToString(f);
     });
 }
 
-
-void DynamicProfilePanel::render_focallen(
-    Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter)
+void DynamicProfilePanel::render_focallen(Gtk::CellRenderer *cell,
+                                          const Gtk::TreeModel::iterator &iter)
 {
     RENDER_RANGE_(double, focallen, to_str);
 }
 
-
 void DynamicProfilePanel::render_shutterspeed(
     Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter)
 {
     RENDER_RANGE_(double, shutterspeed,
-                   rtengine::FramesMetaData::shutterToString);
+                  rtengine::FramesMetaData::shutterToString);
 }
 
-
-void DynamicProfilePanel::render_expcomp(
-    Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter)
+void DynamicProfilePanel::render_expcomp(Gtk::CellRenderer *cell,
+                                         const Gtk::TreeModel::iterator &iter)
 {
     RENDER_RANGE_(double, expcomp, to_str);
 }
 
 #undef RENDER_RANGE_
 
-#define RENDER_OPTIONAL_(name) \
-    auto row = *iter; \
-    Gtk::CellRendererText *ct = static_cast<Gtk::CellRendererText *>(cell); \
-    DynamicProfileRule::Optional o = row[columns_. name]; \
-    if (o.enabled) { \
-        ct->property_text() = o.value; \
-    } else { \
-        ct->property_text() = ""; \
+#define RENDER_OPTIONAL_(name)                                                 \
+    auto row = *iter;                                                          \
+    Gtk::CellRendererText *ct = static_cast<Gtk::CellRendererText *>(cell);    \
+    DynamicProfileRule::Optional o = row[columns_.name];                       \
+    if (o.enabled) {                                                           \
+        ct->property_text() = o.value;                                         \
+    } else {                                                                   \
+        ct->property_text() = "";                                              \
     }
 
-void DynamicProfilePanel::render_camera(
-    Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter)
+void DynamicProfilePanel::render_camera(Gtk::CellRenderer *cell,
+                                        const Gtk::TreeModel::iterator &iter)
 {
     RENDER_OPTIONAL_(camera);
 }
 
-
-void DynamicProfilePanel::render_lens(
-    Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter)
+void DynamicProfilePanel::render_lens(Gtk::CellRenderer *cell,
+                                      const Gtk::TreeModel::iterator &iter)
 {
     RENDER_OPTIONAL_(lens);
 }
 
-
-void DynamicProfilePanel::render_software(
-    Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter)
+void DynamicProfilePanel::render_software(Gtk::CellRenderer *cell,
+                                          const Gtk::TreeModel::iterator &iter)
 {
     RENDER_OPTIONAL_(software);
 }
 
-
-void DynamicProfilePanel::render_filetype(
-    Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter)
+void DynamicProfilePanel::render_filetype(Gtk::CellRenderer *cell,
+                                          const Gtk::TreeModel::iterator &iter)
 {
     RENDER_OPTIONAL_(filetype);
 }
 
-
-void DynamicProfilePanel::render_imagetype(
-    Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter)
+void DynamicProfilePanel::render_imagetype(Gtk::CellRenderer *cell,
+                                           const Gtk::TreeModel::iterator &iter)
 {
     auto row = *iter;
     Gtk::CellRendererText *ct = static_cast<Gtk::CellRendererText *>(cell);
     DynamicProfileRule::Optional o = row[columns_.imagetype];
     if (o.enabled) {
-        ct->property_text() = M(std::string("DYNPROFILEEDITOR_IMGTYPE_") + o.value.uppercase());
+        ct->property_text() =
+            M(std::string("DYNPROFILEEDITOR_IMGTYPE_") + o.value.uppercase());
     } else {
         ct->property_text() = "";
     }
 }
 
-
-void DynamicProfilePanel::render_customdata(Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter)
+void DynamicProfilePanel::render_customdata(
+    Gtk::CellRenderer *cell, const Gtk::TreeModel::iterator &iter)
 {
     auto row = *iter;
     Gtk::CellRendererText *ct = static_cast<Gtk::CellRendererText *>(cell);
     DynamicProfileRule::CustomMetadata m = row[columns_.customdata];
     if (m.enabled) {
-        ct->property_text() = std::to_string(m.value.size()) + " " + M("DYNPROFILEEDITOR_CUSTOMDATA_TAGS");
+        ct->property_text() = std::to_string(m.value.size()) + " " +
+                              M("DYNPROFILEEDITOR_CUSTOMDATA_TAGS");
     } else {
         ct->property_text() = "";
     }
 }
 
-
 #undef RENDER_OPTIONAL_
 
 void DynamicProfilePanel::on_button_up()
@@ -587,7 +578,6 @@ void DynamicProfilePanel::on_button_down()
     }
 }
 
-
 void DynamicProfilePanel::on_button_delete()
 {
     auto s = treeview_.get_selection();
@@ -600,11 +590,10 @@ void DynamicProfilePanel::on_button_delete()
     treemodel_->erase(it);
 }
 
-
 void DynamicProfilePanel::on_button_new()
 {
     EditDialog d(M("DYNPROFILEEDITOR_NEW_RULE"),
-                  static_cast<Gtk::Window &>(*get_toplevel()));
+                 static_cast<Gtk::Window &>(*get_toplevel()));
     int status = d.run();
 
     if (status == 1) {
@@ -613,7 +602,6 @@ void DynamicProfilePanel::on_button_new()
     }
 }
 
-
 void DynamicProfilePanel::on_button_edit()
 {
     auto s = treeview_.get_selection();
@@ -623,7 +611,7 @@ void DynamicProfilePanel::on_button_edit()
     }
 
     EditDialog d(M("DYNPROFILEEDITOR_EDIT_RULE"),
-                  static_cast<Gtk::Window &>(*get_toplevel()));
+                 static_cast<Gtk::Window &>(*get_toplevel()));
     Gtk::TreeModel::Row row = *(s->get_selected());
     d.set_rule(to_rule(row));
     int status = d.run();
@@ -633,7 +621,6 @@ void DynamicProfilePanel::on_button_edit()
     }
 }
 
-
 void DynamicProfilePanel::on_button_reset()
 {
     auto ps = ProfileStore::getInstance();
@@ -643,8 +630,6 @@ void DynamicProfilePanel::on_button_reset()
     ps->setRules(rules);
 }
 
-
-
 void DynamicProfilePanel::save()
 {
     std::vector<DynamicProfileRule> rules;
