@@ -1,114 +1,127 @@
 /*
-*  This file is part of RawTherapee.
-*
-*  Copyright (c) 2012 Oliver Duis <oduis@oliverduis.de>
-*
-*  RawTherapee is free software: you can redistribute it and/or modify
-*  it under the terms of the GNU General Public License as published by
-*  the Free Software Foundation, either version 3 of the License, or
-*  (at your option) any later version.
-*
-*  RawTherapee is distributed in the hope that it will be useful,
-*  but WITHOUT ANY WARRANTY; without even the implied warranty of
-*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*  GNU General Public License for more details.
-*
-*  You should have received a copy of the GNU General Public License
-*  along with RawTherapee.  If not, see <http://www.gnu.org/licenses/>.
-*/
+ *  This file is part of RawTherapee.
+ *
+ *  Copyright (c) 2012 Oliver Duis <oduis@oliverduis.de>
+ *
+ *  RawTherapee is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  RawTherapee is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with RawTherapee.  If not, see <http://www.gnu.org/licenses/>.
+ */
+#include "lensprofile.h"
+#include "../rtengine/lcp.h"
+#include "../rtengine/lensexif.h"
+#include "../rtengine/rtlensfun.h"
+#include "eventmapper.h"
+#include "guiutils.h"
+#include "rtimage.h"
 #include <glibmm.h>
 #include <iostream>
-#include "lensprofile.h"
-#include "guiutils.h"
-#include "../rtengine/lcp.h"
-#include <sstream>
-#include "rtimage.h"
-#include "../rtengine/rtlensfun.h"
 #include <map>
 #include <set>
-#include "../rtengine/lensexif.h"
-#include "eventmapper.h"
+#include <sstream>
 #ifdef EXIF
-#  undef EXIF
+#undef EXIF
 #endif
 
 using namespace rtengine;
 using namespace rtengine::procparams;
 
-LensProfilePanel::LensProfilePanel() :
-    FoldableToolPanel(this, "lensprof", M("TP_LENSPROFILE_LABEL"), false, true, true),
-    lcModeChanged(false),
-    lcpFileChanged(false),
-    useDistChanged(false),
-    useVignChanged(false),
-    useCAChanged(false),
-    useLensfunChanged(false),
-    lensfunAutoChanged(false),
-    lensfunCameraChanged(false),
-    lensfunLensChanged(false),
-    //allowFocusDep(true),
-    isRaw(true),
-    metadata(nullptr),
-    modesGrid(Gtk::manage(new Gtk::Grid())),
-    distGrid(Gtk::manage((new Gtk::Grid()))),
-    corrExif(Gtk::manage((new Gtk::RadioButton(corrGroup, M("TP_LENSPROFILE_CORRECTION_EXIF"))))),
-    corrLensfunAutoRB(Gtk::manage((new Gtk::RadioButton(corrGroup, M("TP_LENSPROFILE_CORRECTION_AUTOMATCH"))))),
-    corrLensfunManualRB(Gtk::manage((new Gtk::RadioButton(corrGroup, M("TP_LENSPROFILE_CORRECTION_MANUAL"))))),
-    corrLcpFileRB(Gtk::manage((new Gtk::RadioButton(corrGroup, M("TP_LENSPROFILE_CORRECTION_LCPFILE"))))),
-    corrLcpFileChooser(Gtk::manage((new MyFileChooserButton(M("TP_LENSPROFILE_LABEL"), Gtk::FILE_CHOOSER_ACTION_OPEN)))),
-    lensfunCamerasLbl(Gtk::manage((new Gtk::Label(M("EXIFFILTER_CAMERA"))))),
-    lensfunCameras(Gtk::manage((new MyComboBox()))),
-    lensfunLensesLbl(Gtk::manage((new Gtk::Label(M("EXIFFILTER_LENS"))))),
-    lensfunLenses(Gtk::manage((new MyComboBox()))),
-    warning(Gtk::manage(new RTImage("warning.svg"))),
-    ckbUseDist(Gtk::manage((new Gtk::CheckButton(M("TP_LENSPROFILE_USE_GEOMETRIC"))))),
-    ckbUseVign(Gtk::manage((new Gtk::CheckButton(M("TP_LENSPROFILE_USE_VIGNETTING"))))),
-    ckbUseCA(Gtk::manage((new Gtk::CheckButton(M("TP_LENSPROFILE_USE_CA")))))
+LensProfilePanel::LensProfilePanel()
+    : FoldableToolPanel(this, "lensprof", M("TP_LENSPROFILE_LABEL"), false,
+                        true, true),
+      lcModeChanged(false), lcpFileChanged(false), useDistChanged(false),
+      useVignChanged(false), useCAChanged(false), useLensfunChanged(false),
+      lensfunAutoChanged(false), lensfunCameraChanged(false),
+      lensfunLensChanged(false),
+      // allowFocusDep(true),
+      isRaw(true), metadata(nullptr), modesGrid(Gtk::manage(new Gtk::Grid())),
+      distGrid(Gtk::manage((new Gtk::Grid()))),
+      corrExif(Gtk::manage((new Gtk::RadioButton(
+          corrGroup, M("TP_LENSPROFILE_CORRECTION_EXIF"))))),
+      corrLensfunAutoRB(Gtk::manage((new Gtk::RadioButton(
+          corrGroup, M("TP_LENSPROFILE_CORRECTION_AUTOMATCH"))))),
+      corrLensfunManualRB(Gtk::manage((new Gtk::RadioButton(
+          corrGroup, M("TP_LENSPROFILE_CORRECTION_MANUAL"))))),
+      corrLcpFileRB(Gtk::manage((new Gtk::RadioButton(
+          corrGroup, M("TP_LENSPROFILE_CORRECTION_LCPFILE"))))),
+      corrLcpFileChooser(Gtk::manage((new MyFileChooserButton(
+          M("TP_LENSPROFILE_LABEL"), Gtk::FILE_CHOOSER_ACTION_OPEN)))),
+      lensfunCamerasLbl(Gtk::manage((new Gtk::Label(M("EXIFFILTER_CAMERA"))))),
+      lensfunCameras(Gtk::manage((new MyComboBox()))),
+      lensfunLensesLbl(Gtk::manage((new Gtk::Label(M("EXIFFILTER_LENS"))))),
+      lensfunLenses(Gtk::manage((new MyComboBox()))),
+      warning(Gtk::manage(new RTImage("warning.svg"))),
+      ckbUseDist(Gtk::manage(
+          (new Gtk::CheckButton(M("TP_LENSPROFILE_USE_GEOMETRIC"))))),
+      ckbUseVign(Gtk::manage(
+          (new Gtk::CheckButton(M("TP_LENSPROFILE_USE_VIGNETTING"))))),
+      ckbUseCA(Gtk::manage((new Gtk::CheckButton(M("TP_LENSPROFILE_USE_CA")))))
 {
-    EvToolEnabled.set_action(rtengine::DARKFRAME); // might need to redo vignetting
+    EvToolEnabled.set_action(
+        rtengine::DARKFRAME); // might need to redo vignetting
     EvToolReset.set_action(rtengine::DARKFRAME);
-    
+
     if (!lf) {
         lf = new LFDbHelper();
     }
 
     // Main containers:
 
-    Gtk::Frame *nodesFrame = Gtk::manage(new Gtk::Frame(M("TP_LENSPROFILE_MODE_HEADER")));
+    Gtk::Frame *nodesFrame =
+        Gtk::manage(new Gtk::Frame(M("TP_LENSPROFILE_MODE_HEADER")));
 
     modesGrid->get_style_context()->add_class("grid-spacing");
-    setExpandAlignProperties(modesGrid, true, false, Gtk::ALIGN_FILL, Gtk::ALIGN_CENTER);
+    setExpandAlignProperties(modesGrid, true, false, Gtk::ALIGN_FILL,
+                             Gtk::ALIGN_CENTER);
 
-    Gtk::Frame *distFrame = Gtk::manage(new Gtk::Frame(M("TP_LENSPROFILE_USE_HEADER")));
+    Gtk::Frame *distFrame =
+        Gtk::manage(new Gtk::Frame(M("TP_LENSPROFILE_USE_HEADER")));
 
     distGrid->get_style_context()->add_class("grid-spacing");
-    setExpandAlignProperties(distGrid, true, false, Gtk::ALIGN_FILL, Gtk::ALIGN_CENTER);
+    setExpandAlignProperties(distGrid, true, false, Gtk::ALIGN_FILL,
+                             Gtk::ALIGN_CENTER);
 
     // Mode choice widgets:
 
-    setExpandAlignProperties(corrLcpFileChooser, true, false, Gtk::ALIGN_FILL, Gtk::ALIGN_CENTER);
+    setExpandAlignProperties(corrLcpFileChooser, true, false, Gtk::ALIGN_FILL,
+                             Gtk::ALIGN_CENTER);
 
     // Manually-selected profile widgets:
 
-    setExpandAlignProperties(lensfunCamerasLbl, false, false, Gtk::ALIGN_END, Gtk::ALIGN_CENTER);
+    setExpandAlignProperties(lensfunCamerasLbl, false, false, Gtk::ALIGN_END,
+                             Gtk::ALIGN_CENTER);
 
     lensfunCameras->set_model(lf->lensfunCameraModel);
     lensfunCameras->pack_start(lf->lensfunModelCam.model);
     lensfunCameras->setPreferredWidth(50, 120);
-    setExpandAlignProperties(lensfunCameras, true, false, Gtk::ALIGN_FILL, Gtk::ALIGN_CENTER);
+    setExpandAlignProperties(lensfunCameras, true, false, Gtk::ALIGN_FILL,
+                             Gtk::ALIGN_CENTER);
 
-    Gtk::CellRendererText* const camerasCellRenderer = static_cast<Gtk::CellRendererText*>(lensfunCameras->get_first_cell());
+    Gtk::CellRendererText *const camerasCellRenderer =
+        static_cast<Gtk::CellRendererText *>(lensfunCameras->get_first_cell());
     camerasCellRenderer->property_ellipsize() = Pango::ELLIPSIZE_MIDDLE;
     camerasCellRenderer->property_ellipsize_set() = true;
 
-    setExpandAlignProperties(lensfunLensesLbl, false, false, Gtk::ALIGN_END, Gtk::ALIGN_CENTER);
+    setExpandAlignProperties(lensfunLensesLbl, false, false, Gtk::ALIGN_END,
+                             Gtk::ALIGN_CENTER);
 
     lensfunLenses->set_model(lf->lensfunLensModel);
     lensfunLenses->pack_start(lf->lensfunModelLens.prettylens);
     lensfunLenses->setPreferredWidth(50, 120);
-    setExpandAlignProperties(lensfunLenses, true, false, Gtk::ALIGN_FILL, Gtk::ALIGN_CENTER);
+    setExpandAlignProperties(lensfunLenses, true, false, Gtk::ALIGN_FILL,
+                             Gtk::ALIGN_CENTER);
 
-    Gtk::CellRendererText* const lensesCellRenderer = static_cast<Gtk::CellRendererText*>(lensfunLenses->get_first_cell());
+    Gtk::CellRendererText *const lensesCellRenderer =
+        static_cast<Gtk::CellRendererText *>(lensfunLenses->get_first_cell());
     lensesCellRenderer->property_ellipsize() = Pango::ELLIPSIZE_MIDDLE;
     lensesCellRenderer->property_ellipsize_set() = true;
 
@@ -123,11 +136,13 @@ LensProfilePanel::LensProfilePanel() :
     filterLCP->add_pattern("*.LCP");
     corrLcpFileChooser->add_filter(filterLCP);
 
-    const Glib::ustring defDir = LCPStore::getInstance()->getDefaultCommonDirectory();
+    const Glib::ustring defDir =
+        LCPStore::getInstance()->getDefaultCommonDirectory();
 
     if (!defDir.empty()) {
 #ifdef WIN32
-        corrLcpFileChooser->set_show_hidden(true);  // ProgramData is hidden on Windows
+        corrLcpFileChooser->set_show_hidden(
+            true); // ProgramData is hidden on Windows
 #endif
         corrLcpFileChooser->set_current_folder(defDir);
     } else if (!options.lastLensProfileDir.empty()) {
@@ -167,26 +182,39 @@ LensProfilePanel::LensProfilePanel() :
     // Attach grids:
     nodesFrame->add(*modesGrid);
     distFrame->add(*distGrid);
-    
+
     pack_start(*nodesFrame, Gtk::PACK_EXPAND_WIDGET);
     pack_start(*distFrame, Gtk::PACK_EXPAND_WIDGET);
 
     // Signals:
 
-    conLCPFile = corrLcpFileChooser->signal_file_set().connect(sigc::mem_fun(*this, &LensProfilePanel::onLCPFileChanged));
-    conUseDist = ckbUseDist->signal_toggled().connect(sigc::mem_fun(*this, &LensProfilePanel::onUseDistChanged));
-    ckbUseVign->signal_toggled().connect(sigc::mem_fun(*this, &LensProfilePanel::onUseVignChanged));
-    ckbUseCA->signal_toggled().connect(sigc::mem_fun(*this, &LensProfilePanel::onUseCAChanged));
+    conLCPFile = corrLcpFileChooser->signal_file_set().connect(
+        sigc::mem_fun(*this, &LensProfilePanel::onLCPFileChanged));
+    conUseDist = ckbUseDist->signal_toggled().connect(
+        sigc::mem_fun(*this, &LensProfilePanel::onUseDistChanged));
+    ckbUseVign->signal_toggled().connect(
+        sigc::mem_fun(*this, &LensProfilePanel::onUseVignChanged));
+    ckbUseCA->signal_toggled().connect(
+        sigc::mem_fun(*this, &LensProfilePanel::onUseCAChanged));
 
-    lensfunCameras->signal_changed().connect(sigc::mem_fun(*this, &LensProfilePanel::onLensfunCameraChanged));
-    lensfunLenses->signal_changed().connect(sigc::mem_fun(*this, &LensProfilePanel::onLensfunLensChanged));
-    corrExif->signal_toggled().connect(sigc::bind(sigc::mem_fun(*this, &LensProfilePanel::onCorrModeChanged), corrExif));
-    corrLensfunAutoRB->signal_toggled().connect(sigc::bind(sigc::mem_fun(*this, &LensProfilePanel::onCorrModeChanged), corrLensfunAutoRB));
-    corrLensfunManualRB->signal_toggled().connect(sigc::bind(sigc::mem_fun(*this, &LensProfilePanel::onCorrModeChanged), corrLensfunManualRB));
-    corrLcpFileRB->signal_toggled().connect(sigc::bind(sigc::mem_fun(*this, &LensProfilePanel::onCorrModeChanged), corrLcpFileRB));
+    lensfunCameras->signal_changed().connect(
+        sigc::mem_fun(*this, &LensProfilePanel::onLensfunCameraChanged));
+    lensfunLenses->signal_changed().connect(
+        sigc::mem_fun(*this, &LensProfilePanel::onLensfunLensChanged));
+    corrExif->signal_toggled().connect(sigc::bind(
+        sigc::mem_fun(*this, &LensProfilePanel::onCorrModeChanged), corrExif));
+    corrLensfunAutoRB->signal_toggled().connect(
+        sigc::bind(sigc::mem_fun(*this, &LensProfilePanel::onCorrModeChanged),
+                   corrLensfunAutoRB));
+    corrLensfunManualRB->signal_toggled().connect(
+        sigc::bind(sigc::mem_fun(*this, &LensProfilePanel::onCorrModeChanged),
+                   corrLensfunManualRB));
+    corrLcpFileRB->signal_toggled().connect(
+        sigc::bind(sigc::mem_fun(*this, &LensProfilePanel::onCorrModeChanged),
+                   corrLcpFileRB));
 }
 
-void LensProfilePanel::read(const rtengine::procparams::ProcParams* pp)
+void LensProfilePanel::read(const rtengine::procparams::ProcParams *pp)
 {
     disableListener();
     conUseDist.block(true);
@@ -194,64 +222,68 @@ void LensProfilePanel::read(const rtengine::procparams::ProcParams* pp)
     setEnabled(true);
 
     switch (pp->lensProf.lcMode) {
-        case procparams::LensProfParams::LcMode::LCP: {
-            corrLcpFileRB->set_active(true);
-            break;
-        }
+    case procparams::LensProfParams::LcMode::LCP: {
+        corrLcpFileRB->set_active(true);
+        break;
+    }
 
-        case procparams::LensProfParams::LcMode::LENSFUNAUTOMATCH: {
-            corrLensfunAutoRB->set_active(true);
-            break;
-        }
+    case procparams::LensProfParams::LcMode::LENSFUNAUTOMATCH: {
+        corrLensfunAutoRB->set_active(true);
+        break;
+    }
 
-        case procparams::LensProfParams::LcMode::LENSFUNMANUAL: {
-            corrLensfunManualRB->set_active(true);
-            break;
-        }
+    case procparams::LensProfParams::LcMode::LENSFUNMANUAL: {
+        corrLensfunManualRB->set_active(true);
+        break;
+    }
 
-        case procparams::LensProfParams::LcMode::EXIF: {
-            if (metadata) {
-                if (rtengine::ExifLensCorrection::ok(metadata)) {
-                    corrExif->set_active(true);
-                    corrExif->set_sensitive(true);
-                    ckbUseCA->set_sensitive(true);
-                } else {
-                    corrExif->set_sensitive(false);
-                    corrLensfunAutoRB->set_active(true);
-                }
+    case procparams::LensProfParams::LcMode::EXIF: {
+        if (metadata) {
+            if (rtengine::ExifLensCorrection::ok(metadata)) {
+                corrExif->set_active(true);
+                corrExif->set_sensitive(true);
+                ckbUseCA->set_sensitive(true);
             } else {
                 corrExif->set_sensitive(false);
-                setEnabled(false);
+                corrLensfunAutoRB->set_active(true);
             }
-            break;
-        }
-            
-        case procparams::LensProfParams::LcMode::NONE: {
+        } else {
+            corrExif->set_sensitive(false);
             setEnabled(false);
-            break;
         }
+        break;
+    }
+
+    case procparams::LensProfParams::LcMode::NONE: {
+        setEnabled(false);
+        break;
+    }
     }
 
     if (pp->lensProf.lcpFile.empty()) {
-        const Glib::ustring lastFolder = corrLcpFileChooser->get_current_folder();
+        const Glib::ustring lastFolder =
+            corrLcpFileChooser->get_current_folder();
         corrLcpFileChooser->set_current_folder(lastFolder);
         corrLcpFileChooser->unselect_all();
         bindCurrentFolder(*corrLcpFileChooser, options.lastLensProfileDir);
         updateDisabled();
-    } else if (LCPStore::getInstance()->isValidLCPFileName(pp->lensProf.lcpFile)) {
+    } else if (LCPStore::getInstance()->isValidLCPFileName(
+                   pp->lensProf.lcpFile)) {
         corrLcpFileChooser->set_filename(pp->lensProf.lcpFile);
 
         if (corrLcpFileRB->get_active()) {
             updateDisabled();
         }
     } else {
-        corrLcpFileChooser->unselect_filename(corrLcpFileChooser->get_filename());
+        corrLcpFileChooser->unselect_filename(
+            corrLcpFileChooser->get_filename());
         updateDisabled();
     }
 
-    setManualParamsVisibility(corrLensfunAutoRB->get_active() || corrLensfunManualRB->get_active());
-    
-    const LFDatabase* const db = LFDatabase::getInstance();
+    setManualParamsVisibility(corrLensfunAutoRB->get_active() ||
+                              corrLensfunManualRB->get_active());
+
+    const LFDatabase *const db = LFDatabase::getInstance();
     LFCamera c;
 
     if (pp->lensProf.lfAutoMatch()) {
@@ -272,37 +304,37 @@ void LensProfilePanel::read(const rtengine::procparams::ProcParams* pp)
         setLensfunLens(pp->lensProf.lfLens);
     }
 
-
     ckbUseDist->set_active(pp->lensProf.useDist);
     ckbUseVign->set_active(pp->lensProf.useVign);
     ckbUseCA->set_active(pp->lensProf.useCA);
-    
-    lcModeChanged = lcpFileChanged = useDistChanged = useVignChanged = useCAChanged = false;
-    useLensfunChanged = lensfunAutoChanged = lensfunCameraChanged = lensfunLensChanged = false;
-    
+
+    lcModeChanged = lcpFileChanged = useDistChanged = useVignChanged =
+        useCAChanged = false;
+    useLensfunChanged = lensfunAutoChanged = lensfunCameraChanged =
+        lensfunLensChanged = false;
+
     updateLensfunWarning();
     enableListener();
     conUseDist.block(false);
 }
 
-void LensProfilePanel::write(rtengine::procparams::ProcParams* pp)
+void LensProfilePanel::write(rtengine::procparams::ProcParams *pp)
 {
     if (!getEnabled()) {
         pp->lensProf.lcMode = procparams::LensProfParams::LcMode::NONE;
     } else if (corrLcpFileRB->get_active()) {
         pp->lensProf.lcMode = procparams::LensProfParams::LcMode::LCP;
-    }
-    else if (corrLensfunManualRB->get_active()) {
+    } else if (corrLensfunManualRB->get_active()) {
         pp->lensProf.lcMode = procparams::LensProfParams::LcMode::LENSFUNMANUAL;
-    }
-    else if (corrLensfunAutoRB->get_active()) {
-        pp->lensProf.lcMode = procparams::LensProfParams::LcMode::LENSFUNAUTOMATCH;
-    }
-    else if (corrExif->get_active()) {
+    } else if (corrLensfunAutoRB->get_active()) {
+        pp->lensProf.lcMode =
+            procparams::LensProfParams::LcMode::LENSFUNAUTOMATCH;
+    } else if (corrExif->get_active()) {
         pp->lensProf.lcMode = procparams::LensProfParams::LcMode::EXIF;
     }
 
-    if (LCPStore::getInstance()->isValidLCPFileName(corrLcpFileChooser->get_filename())) {
+    if (LCPStore::getInstance()->isValidLCPFileName(
+            corrLcpFileChooser->get_filename())) {
         pp->lensProf.lcpFile = corrLcpFileChooser->get_filename();
     } else {
         pp->lensProf.lcpFile = "";
@@ -310,7 +342,7 @@ void LensProfilePanel::write(rtengine::procparams::ProcParams* pp)
 
     pp->lensProf.useDist = ckbUseDist->get_active();
     pp->lensProf.useVign = ckbUseVign->get_active();
-    pp->lensProf.useCA   = ckbUseCA->get_active();
+    pp->lensProf.useCA = ckbUseCA->get_active();
 
     const auto itc = lensfunCameras->get_active();
 
@@ -331,14 +363,14 @@ void LensProfilePanel::write(rtengine::procparams::ProcParams* pp)
     }
 }
 
-void LensProfilePanel::setRawMeta(bool raw, const rtengine::FramesMetaData* pMeta)
+void LensProfilePanel::setRawMeta(bool raw,
+                                  const rtengine::FramesMetaData *pMeta)
 {
     disableListener();
     // if ((!raw || pMeta->getFocusDist() <= 0)) {
 
-    //     // CA is very focus layer dependent, otherwise it might even worsen things
-    //     allowFocusDep = false;
-    //     ckbUseCA->set_active(false);
+    //     // CA is very focus layer dependent, otherwise it might even worsen
+    //     things allowFocusDep = false; ckbUseCA->set_active(false);
     //     ckbUseCA->set_sensitive(false);
     // }
 
@@ -350,7 +382,7 @@ void LensProfilePanel::setRawMeta(bool raw, const rtengine::FramesMetaData* pMet
             corrExif->set_sensitive(false);
         } else {
             ckbUseCA->set_sensitive(true);
-        }        
+        }
     } else {
         corrExif->set_sensitive(false);
     }
@@ -360,7 +392,8 @@ void LensProfilePanel::setRawMeta(bool raw, const rtengine::FramesMetaData* pMet
 void LensProfilePanel::onLCPFileChanged()
 {
     lcpFileChanged = true;
-    const bool valid = LCPStore::getInstance()->isValidLCPFileName(corrLcpFileChooser->get_filename());
+    const bool valid = LCPStore::getInstance()->isValidLCPFileName(
+        corrLcpFileChooser->get_filename());
     updateDisabled();
 
     if (listener) {
@@ -370,7 +403,9 @@ void LensProfilePanel::onLCPFileChanged()
             enableListener();
         }
 
-        listener->panelChanged(EvLCPFile, Glib::path_get_basename(corrLcpFileChooser->get_filename()));
+        listener->panelChanged(
+            EvLCPFile,
+            Glib::path_get_basename(corrLcpFileChooser->get_filename()));
     }
 }
 
@@ -383,7 +418,9 @@ void LensProfilePanel::onUseDistChanged()
     }
 
     if (listener) {
-        listener->panelChanged(EvLCPUseDist, ckbUseDist->get_active() ? M("GENERAL_ENABLED") : M("GENERAL_DISABLED"));
+        listener->panelChanged(EvLCPUseDist, ckbUseDist->get_active()
+                                                 ? M("GENERAL_ENABLED")
+                                                 : M("GENERAL_DISABLED"));
     }
 }
 
@@ -396,7 +433,9 @@ void LensProfilePanel::onUseVignChanged()
     }
 
     if (listener) {
-        listener->panelChanged(EvLCPUseVign, ckbUseVign->get_active() ? M("GENERAL_ENABLED") : M("GENERAL_DISABLED"));
+        listener->panelChanged(EvLCPUseVign, ckbUseVign->get_active()
+                                                 ? M("GENERAL_ENABLED")
+                                                 : M("GENERAL_DISABLED"));
     }
 }
 
@@ -409,11 +448,12 @@ void LensProfilePanel::onUseCAChanged()
     }
 
     if (listener) {
-        listener->panelChanged(EvLCPUseCA, ckbUseCA->get_active() ? M("GENERAL_ENABLED") : M("GENERAL_DISABLED"));
+        listener->panelChanged(EvLCPUseCA, ckbUseCA->get_active()
+                                               ? M("GENERAL_ENABLED")
+                                               : M("GENERAL_DISABLED"));
     }
 }
 
-
 void LensProfilePanel::onLensfunCameraChanged()
 {
     const auto iter = lensfunCameras->get_active();
@@ -454,7 +494,7 @@ void LensProfilePanel::onLensfunLensChanged()
     updateLensfunWarning();
 }
 
-void LensProfilePanel::onCorrModeChanged(const Gtk::RadioButton* rbChanged)
+void LensProfilePanel::onCorrModeChanged(const Gtk::RadioButton *rbChanged)
 {
     if (rbChanged->get_active()) {
         Glib::ustring mode;
@@ -468,8 +508,9 @@ void LensProfilePanel::onCorrModeChanged(const Gtk::RadioButton* rbChanged)
 
             const bool disabled = disableListener();
             if (metadata) {
-                const LFDatabase* const db = LFDatabase::getInstance();
-                const LFCamera c = db->findCamera(metadata->getMake(), metadata->getModel());
+                const LFDatabase *const db = LFDatabase::getInstance();
+                const LFCamera c =
+                    db->findCamera(metadata->getMake(), metadata->getModel());
                 const LFLens l = db->findLens(c, metadata->getLens());
                 setLensfunCamera(c.getMake(), c.getModel());
                 setLensfunLens(l.getLens());
@@ -477,9 +518,9 @@ void LensProfilePanel::onCorrModeChanged(const Gtk::RadioButton* rbChanged)
             if (disabled) {
                 enableListener();
             }
-            
+
             mode = M("TP_LENSPROFILE_CORRECTION_AUTOMATCH");
-            
+
         } else if (rbChanged == corrLensfunManualRB) {
             lcModeChanged = true;
             useLensfunChanged = true;
@@ -489,21 +530,21 @@ void LensProfilePanel::onCorrModeChanged(const Gtk::RadioButton* rbChanged)
             lcpFileChanged = false;
 
             mode = M("TP_LENSPROFILE_CORRECTION_MANUAL");
-            
+
         } else if (rbChanged == corrLcpFileRB || rbChanged == corrExif) {
             lcModeChanged = true;
             useLensfunChanged = true;
             lensfunAutoChanged = true;
             lcpFileChanged = true;
 
-
-            mode = M("TP_LENSPROFILE_CORRECTION_LCPFILE");            
+            mode = M("TP_LENSPROFILE_CORRECTION_LCPFILE");
         }
 
         updateLensfunWarning();
         updateDisabled();
 
-        if (rbChanged == corrLensfunManualRB || (rbChanged == corrLensfunAutoRB)) {
+        if (rbChanged == corrLensfunManualRB ||
+            (rbChanged == corrLensfunAutoRB)) {
             setManualParamsVisibility(true);
         } else {
             setManualParamsVisibility(false);
@@ -552,21 +593,23 @@ void LensProfilePanel::LFDbHelper::fillLensfunCameras()
     std::map<Glib::ustring, std::set<Glib::ustring>> camnames;
     const auto camlist = LFDatabase::getInstance()->getCameras();
 
-    for (const auto& c : camlist) {
+    for (const auto &c : camlist) {
         camnames[c.getMake()].insert(c.getModel());
 
         if (options.rtSettings.verbose > 1) {
-            std::cout << "  found: " << c.getDisplayString().c_str() << std::endl;
+            std::cout << "  found: " << c.getDisplayString().c_str()
+                      << std::endl;
         }
     }
 
-    for (const auto& p : camnames) {
+    for (const auto &p : camnames) {
         Gtk::TreeModel::Row row = *(lensfunCameraModel->append());
         row[lensfunModelCam.make] = p.first;
         row[lensfunModelCam.model] = p.first;
 
-        for (const auto& c : p.second) {
-            Gtk::TreeModel::Row child = *(lensfunCameraModel->append(row.children()));
+        for (const auto &c : p.second) {
+            Gtk::TreeModel::Row child =
+                *(lensfunCameraModel->append(row.children()));
             child[lensfunModelCam.make] = p.first;
             child[lensfunModelCam.model] = c;
         }
@@ -582,27 +625,30 @@ void LensProfilePanel::LFDbHelper::fillLensfunLenses()
     std::map<Glib::ustring, std::set<Glib::ustring>> lenses;
     const auto lenslist = LFDatabase::getInstance()->getLenses();
 
-    for (const auto& l : lenslist) {
-        const auto& name = l.getLens();
-        const auto& make = l.getMake();
+    for (const auto &l : lenslist) {
+        const auto &name = l.getLens();
+        const auto &make = l.getMake();
         lenses[make].insert(name);
 
         if (options.rtSettings.verbose > 1) {
-            std::cout << "  found: " << l.getDisplayString().c_str() << std::endl;
+            std::cout << "  found: " << l.getDisplayString().c_str()
+                      << std::endl;
         }
     }
 
-    for (const auto& p : lenses) {
+    for (const auto &p : lenses) {
         Gtk::TreeModel::Row row = *(lensfunLensModel->append());
         row[lensfunModelLens.lens] = p.first;
         row[lensfunModelLens.prettylens] = p.first;
 
         for (auto &c : p.second) {
-            Gtk::TreeModel::Row child = *(lensfunLensModel->append(row.children()));
+            Gtk::TreeModel::Row child =
+                *(lensfunLensModel->append(row.children()));
             child[lensfunModelLens.lens] = c;
 
             if (c.find(p.first, p.first.size() + 1) == p.first.size() + 1) {
-                child[lensfunModelLens.prettylens] = c.substr(p.first.size() + 1);
+                child[lensfunModelLens.prettylens] =
+                    c.substr(p.first.size() + 1);
             } else {
                 child[lensfunModelLens.prettylens] = c;
             }
@@ -615,27 +661,30 @@ void LensProfilePanel::updateDisabled()
     ckbUseDist->set_sensitive(true);
     ckbUseVign->set_sensitive(true);
     ckbUseCA->set_sensitive(true);
-    
+
     ckbUseVign->set_sensitive(isRaw);
     // ckbUseCA->set_sensitive(allowFocusDep || corrExif->get_active());
 }
 
-bool LensProfilePanel::setLensfunCamera(const Glib::ustring& make, const Glib::ustring& model)
+bool LensProfilePanel::setLensfunCamera(const Glib::ustring &make,
+                                        const Glib::ustring &model)
 {
     if (!make.empty() && !model.empty()) {
         const auto camera_it = lensfunCameras->get_active();
 
-        if (camera_it && (*camera_it)[lf->lensfunModelCam.make] == make && (*camera_it)[lf->lensfunModelCam.model] == model) {
+        if (camera_it && (*camera_it)[lf->lensfunModelCam.make] == make &&
+            (*camera_it)[lf->lensfunModelCam.model] == model) {
             return true;
         }
 
         // search for the active row
-        for (const auto& row : lf->lensfunCameraModel->children()) {
+        for (const auto &row : lf->lensfunCameraModel->children()) {
             if (row[lf->lensfunModelCam.make] == make) {
-                const auto& c = row.children();
+                const auto &c = row.children();
 
-                for (auto model_it = c.begin(), end = c.end(); model_it != end; ++model_it) {
-                    const auto& childrow = *model_it;
+                for (auto model_it = c.begin(), end = c.end(); model_it != end;
+                     ++model_it) {
+                    const auto &childrow = *model_it;
 
                     if (childrow[lf->lensfunModelCam.model] == model) {
                         lensfunCameras->set_active(model_it);
@@ -652,7 +701,7 @@ bool LensProfilePanel::setLensfunCamera(const Glib::ustring& make, const Glib::u
     return false;
 }
 
-bool LensProfilePanel::setLensfunLens(const Glib::ustring& lens)
+bool LensProfilePanel::setLensfunLens(const Glib::ustring &lens)
 {
     if (!lens.empty()) {
         const auto lens_it = lensfunLenses->get_active();
@@ -663,12 +712,13 @@ bool LensProfilePanel::setLensfunLens(const Glib::ustring& lens)
 
         bool first_maker_found = false;
 
-        for (const auto& row : lf->lensfunLensModel->children()) {
+        for (const auto &row : lf->lensfunLensModel->children()) {
             if (lens.find(row[lf->lensfunModelLens.lens]) == 0) {
-                const auto& c = row.children();
+                const auto &c = row.children();
 
-                for (auto model_it = c.begin(), end = c.end(); model_it != end; ++model_it) {
-                    const auto& childrow = *model_it;
+                for (auto model_it = c.begin(), end = c.end(); model_it != end;
+                     ++model_it) {
+                    const auto &childrow = *model_it;
 
                     if (childrow[lf->lensfunModelLens.lens] == lens) {
                         lensfunLenses->set_active(model_it);
@@ -676,9 +726,10 @@ bool LensProfilePanel::setLensfunLens(const Glib::ustring& lens)
                     }
                 }
 
-                // we do not break immediately here, because there might be multiple makers
-                // sharing the same prefix (e.g. "Leica" and "Leica Camera AG").
-                // therefore, we break below when the lens doesn't match any of them
+                // we do not break immediately here, because there might be
+                // multiple makers sharing the same prefix (e.g. "Leica" and
+                // "Leica Camera AG"). therefore, we break below when the lens
+                // doesn't match any of them
                 first_maker_found = true;
             } else if (first_maker_found) {
                 break;
@@ -698,7 +749,9 @@ bool LensProfilePanel::checkLensfunCanCorrect(bool automatch)
 
     rtengine::procparams::ProcParams lpp;
     write(&lpp);
-    const std::unique_ptr<LFModifier> mod(LFDatabase::getInstance()->findModifier(lpp.lensProf, metadata, 100, 100, lpp.coarse, -1));
+    const std::unique_ptr<LFModifier> mod(
+        LFDatabase::getInstance()->findModifier(lpp.lensProf, metadata, 100,
+                                                100, lpp.coarse, -1));
     return static_cast<bool>(mod);
 }
 
@@ -726,9 +779,9 @@ void LensProfilePanel::updateLensfunWarning()
     ckbUseVign->set_sensitive(isRaw);
     ckbUseDist->set_sensitive(true);
     ckbUseCA->set_sensitive(true);
-        
+
     if (corrLensfunManualRB->get_active() || corrLensfunAutoRB->get_active()) {
-        const LFDatabase* const db = LFDatabase::getInstance();
+        const LFDatabase *const db = LFDatabase::getInstance();
 
         const auto itc = lensfunCameras->get_active();
 
@@ -736,14 +789,16 @@ void LensProfilePanel::updateLensfunWarning()
             return;
         }
 
-        const LFCamera c = db->findCamera((*itc)[lf->lensfunModelCam.make], (*itc)[lf->lensfunModelCam.model]);
+        const LFCamera c = db->findCamera((*itc)[lf->lensfunModelCam.make],
+                                          (*itc)[lf->lensfunModelCam.model]);
         const auto itl = lensfunLenses->get_active();
 
         if (!itl) {
             return;
         }
 
-        const LFLens l = db->findLens(LFCamera(), (*itl)[lf->lensfunModelLens.lens]);
+        const LFLens l =
+            db->findLens(LFCamera(), (*itl)[lf->lensfunModelLens.lens]);
         const float lenscrop = l.getCropFactor();
         const float camcrop = c.getCropFactor();
 
@@ -769,15 +824,13 @@ void LensProfilePanel::updateLensfunWarning()
     }
 }
 
-LensProfilePanel::LFDbHelper* LensProfilePanel::lf(nullptr);
-
+LensProfilePanel::LFDbHelper *LensProfilePanel::lf(nullptr);
 
 void LensProfilePanel::setDefaults(const ProcParams *def)
 {
     initial_params = def->lensProf;
 }
 
-
 void LensProfilePanel::toolReset(bool to_initial)
 {
     ProcParams pp;
