@@ -22,8 +22,7 @@
 #include "options.h"
 #include "rtsurface.h"
 
-namespace
-{
+namespace {
 
 std::map<std::string, Cairo::RefPtr<Cairo::ImageSurface>> surfaceCache;
 
@@ -32,25 +31,28 @@ std::map<std::string, Cairo::RefPtr<Cairo::ImageSurface>> surfaceCache;
 double RTSurface::dpiBack = 0.;
 int RTSurface::scaleBack = 0;
 
-RTSurface::RTSurface () : RTScalable()
+RTSurface::RTSurface(): RTScalable()
 {
-    Cairo::RefPtr<Cairo::ImageSurface> imgSurf(new Cairo::ImageSurface(nullptr, false));
+    Cairo::RefPtr<Cairo::ImageSurface> imgSurf(
+        new Cairo::ImageSurface(nullptr, false));
     surface = imgSurf;
 }
 
-RTSurface::RTSurface(const RTSurface& other) : RTScalable()
+RTSurface::RTSurface(const RTSurface &other): RTScalable()
 {
     surface = other.surface;
 }
 
-RTSurface::RTSurface (Glib::ustring fileName, Glib::ustring rtlFileName) : RTScalable()
+RTSurface::RTSurface(Glib::ustring fileName, Glib::ustring rtlFileName)
+    : RTScalable()
 {
-    Cairo::RefPtr<Cairo::ImageSurface> imgSurf(new Cairo::ImageSurface(nullptr, false));
+    Cairo::RefPtr<Cairo::ImageSurface> imgSurf(
+        new Cairo::ImageSurface(nullptr, false));
     surface = imgSurf;
-    setImage (fileName, rtlFileName);
+    setImage(fileName, rtlFileName);
 }
 
-void RTSurface::setImage (Glib::ustring fileName, Glib::ustring rtlFileName)
+void RTSurface::setImage(Glib::ustring fileName, Glib::ustring rtlFileName)
 {
     Glib::ustring imageName;
 
@@ -60,39 +62,42 @@ void RTSurface::setImage (Glib::ustring fileName, Glib::ustring rtlFileName)
         imageName = fileName;
     }
 
-    changeImage (imageName);
+    changeImage(imageName);
 }
 
-void RTSurface::setDPInScale (const double newDPI, const int newScale)
+void RTSurface::setDPInScale(const double newDPI, const int newScale)
 {
     if (getScale() != newScale || (getScale() == 1 && getDPI() != newDPI)) {
         RTScalable::setDPInScale(newDPI, newScale);
         dpiBack = getDPI();
         scaleBack = getScale();
-        //printf("RTSurface::setDPInScale : New scale = %d & new DPI = %.3f (%.3f asked) -> Reloading all RTSurface\n", scaleBack, dpiBack, newDPI);
+        // printf("RTSurface::setDPInScale : New scale = %d & new DPI = %.3f
+        // (%.3f asked) -> Reloading all RTSurface\n", scaleBack, dpiBack,
+        // newDPI);
         updateImages();
     }
 }
 
-void RTSurface::changeImage (Glib::ustring imageName)
+void RTSurface::changeImage(Glib::ustring imageName)
 {
-    auto iterator = surfaceCache.find (imageName);
+    auto iterator = surfaceCache.find(imageName);
 
-    if (iterator == surfaceCache.end ()) {
+    if (iterator == surfaceCache.end()) {
         surface = loadImage(imageName, getTweakedDPI());
 
-        // HOMBRE: As of now, GDK_SCALE is forced to 1, so setting the Cairo::ImageSurface scale is not required
+        // HOMBRE: As of now, GDK_SCALE is forced to 1, so setting the
+        // Cairo::ImageSurface scale is not required
         //         Anyway, this might be of use one day
         /*
         double x=0., y=0.;
         cairo_surface_get_device_scale(surface->cobj(), &x, &y);
         if (getScale() == 2) {
-            cairo_surface_set_device_scale(surface->cobj(), 0.5, 0.5); // Not sure if it should be 0.5 or 2.0 here !
-            surface->flush();
+            cairo_surface_set_device_scale(surface->cobj(), 0.5, 0.5); // Not
+        sure if it should be 0.5 or 2.0 here ! surface->flush();
         }
         */
 
-        iterator = surfaceCache.emplace (imageName, surface).first;
+        iterator = surfaceCache.emplace(imageName, surface).first;
     }
 
     surface = iterator->second;
@@ -100,7 +105,7 @@ void RTSurface::changeImage (Glib::ustring imageName)
 
 int RTSurface::getWidth() const
 {
-//    return surface ? surface->get_width() : -1;
+    //    return surface ? surface->get_width() : -1;
     if (surface) {
         return surface->get_width() / RTSurface::getDeviceScale();
     } else {
@@ -110,7 +115,7 @@ int RTSurface::getWidth() const
 
 int RTSurface::getHeight() const
 {
-//    return surface ? surface->get_height() : -1;
+    //    return surface ? surface->get_height() : -1;
     if (surface) {
         return surface->get_height() / RTSurface::getDeviceScale();
     } else {
@@ -129,7 +134,7 @@ void RTSurface::updateImages()
     double res = getTweakedDPI();
     for (auto entry : surfaceCache) {
         entry.second = loadImage(entry.first, res);
-        //printf("RTSurface::updateImages : %s\n", entry.first.c_str());
+        // printf("RTSurface::updateImages : %s\n", entry.first.c_str());
     }
 }
 
@@ -138,7 +143,4 @@ void RTSurface::from(Glib::RefPtr<RTSurface> other)
     surface = other->surface;
 }
 
-bool RTSurface::hasSurface() const
-{
-    return surface ? true : false;
-}
+bool RTSurface::hasSurface() const { return surface ? true : false; }
