@@ -19,6 +19,14 @@
 #ifndef _TOOLENUM_
 #define _TOOLENUM_
 
-enum ToolMode {TMNone = -1, TMHand = 0, TMSpotWB = 1, TMCropSelect = 2, TMStraighten = 3, TMColorPicker = 4, TMPerspective = 5};
+enum ToolMode {
+    TMNone = -1,
+    TMHand = 0,
+    TMSpotWB = 1,
+    TMCropSelect = 2,
+    TMStraighten = 3,
+    TMColorPicker = 4,
+    TMPerspective = 5
+};
 
 #endif
